/* SISTEMAS INTEGRADOS TECNISA
   SERVIOS

NOME: EXCLUSAO_DE_DUPLICATA

DESCRIO:
GERAO DE BOLETOS FICTCIOS E EXCLUSO DO BOLETO REAL DE CONTAS A RECEBER
REFERENTES A UMA DUPLICATA QUE EST SENDO EXCLUDA.

P_CDFILIAL    - CDIGO DA FILIAL
P_NRLANCTODUP - NMERO DA DUPLICATA
P_NRLANBOLREC - NMERO DOS BOLETOS - ESTE NR. SER INCREMENTADO DENTRO DA PROCEDURE.
P_IDRESULT    - IDENTIFICADOR DE RESULTADO
                'N' - OK.
                'D' - EXISTEM CONTAS (VENCIMENTOS) DE DUPLICATAS DIFERENTES AGRUPADAS NO MESMO BOLETO.
                'E' - NO EXISTEM CONTAS ASSOCIADAS  DUPLICATA.
                'F' - NMERO DO BOLETO (INTERNO) NO INFORMADO.
                'I' - BOLETOS J BAIXADOS
                'J' - CONTAS OU BOLETOS PARCELADOS
                'L' - CONTA PRORROGADA - (DESATIVADO)

PARA APLICAR E DEBUGAR
-- @C:\WIN_PRJ\SQL\ORACLE\1020_FINSTP_EXCLUSAO_DE_DUPLICATA.SQL;
-- EXECUTE EXCLUSAO_DE_DUPLICATA('9999', '0000000000', '0000000000', :P_IDRESULT)
-- SET SERVEROUTPUT ON
-- DBMS_OUTPUT.PUT_LINE('XX');

CRIAO:
13/01/00 - EDERSON
*/

IF EXISTS (SELECT
              *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE
	           O.NAME = 'EXCLUSAO_DE_DUPLICATA' AND
	           TYPE = 'P' 			              AND
              U.UID = O.UID                    AND
              U.NAME = USER)

DROP PROCEDURE EXCLUSAO_DE_DUPLICATA
GO

CREATE PROCEDURE EXCLUSAO_DE_DUPLICATA
   @P_CDFILIAL    VARCHAR(04),
   @P_NRLANCTODUP VARCHAR(10),
   @P_NRLANBOLREC VARCHAR(10),
   @P_IDRESULT    VARCHAR(01) OUTPUT

AS

   DECLARE @V_CDFILIBOLREC VARCHAR(04);
   DECLARE @V_NRLANBOLREC  VARCHAR(10);
   DECLARE @V_NRPRXLANBOL  VARCHAR(10);
   DECLARE @V_CDCLIENTE    VARCHAR(21);
   DECLARE @V_NRREGFOR     INTEGER;
   DECLARE @V_NRBOLETO     INTEGER;
   DECLARE @V_PEMULTA      FLOAT;
   DECLARE @V_PEMORA       FLOAT;
   DECLARE @V_COUNT        INTEGER;
   DECLARE @V_CTAJBOL      INTEGER;
   DECLARE @V_NRBOLBAIXADO INTEGER;
   DECLARE @V_NRPARCELA    INTEGER;
   DECLARE @V_NRCNTPROR    INTEGER;

   /* VARIVEIS DO CURSOR C_CNTBOL */
   DECLARE @V_CNTBOL_CDFILIBOLREC VARCHAR(04);
   DECLARE @V_CNTBOL_NRLANBOLREC  VARCHAR(10);

   /* VARIVEIS DO CURSOR C_CONTREC */
   DECLARE @V_CNTREC_CDFILIAL     VARCHAR(04);
   DECLARE @V_CNTREC_NRLANCTONF   VARCHAR(10);
   DECLARE @V_CNTREC_NRSEQVENREC  VARCHAR(02);
   DECLARE @V_CNTREC_NRPARCELAREC VARCHAR(02);
   DECLARE @V_CNTREC_CDTPCTRECEB  VARCHAR(06);

   /* VARIVEIS DO CURSOR C_AJBOL */
   DECLARE @V_AJBOL_CDEMPRESA    VARCHAR(02);
   DECLARE @V_AJBOL_CDFILIAL     VARCHAR(04);
   DECLARE @V_AJBOL_DTMOVFLUXO   DATETIME;
   DECLARE @V_AJBOL_IDMOVFLUXO   VARCHAR(01);
   DECLARE @V_AJBOL_CDCLASSFINA  VARCHAR(06);
   DECLARE @V_AJBOL_VRFXAJBOLREC NUMERIC(16,2);
   DECLARE @V_AJBOL_IDAJUCTREC   VARCHAR(01);
   DECLARE @V_AJBOL_CDFILIBOLREC VARCHAR(04);
   DECLARE @V_AJBOL_NRLANBOLREC  VARCHAR(10);
   DECLARE @V_AJBOL_CDAJUCTREC   VARCHAR(04);

   DECLARE @V_CHAVE_NOTA VARCHAR(14);

BEGIN
   SET @P_IDRESULT = 'N';

   /* - VERIFICA SE A DUPLICATA POSSUI CONTAS ASSOCIADAS -------------------- */
   SELECT
      @V_NRREGFOR = COUNT(*)
   FROM
      CONTARECEBER
   WHERE
      (CDFILIALDUP = @P_CDFILIAL) AND
      (NRLANCTODUP = @P_NRLANCTODUP);

   IF @V_NRREGFOR > 0 BEGIN
      DECLARE C_CNTBOL CURSOR FOR
         SELECT
            CDFILIBOLREC,
            NRLANBOLREC
         FROM
            CONTARECEBER
         WHERE
            (CDFILIALDUP = @P_CDFILIAL) AND
            (NRLANCTODUP = @P_NRLANCTODUP);

         OPEN C_CNTBOL;

         FETCH NEXT FROM C_CNTBOL INTO @V_CNTBOL_CDFILIBOLREC, @V_CNTBOL_NRLANBOLREC;

         WHILE (@@FETCH_STATUS = 0) BEGIN

            SELECT
               @V_NRBOLETO = COUNT(*)
            FROM
               (SELECT DISTINCT
                   (CDFILIALDUP + NRLANCTODUP) S
                FROM
                   CONTARECEBER
                WHERE
                   (CDFILIBOLREC = @V_CNTBOL_CDFILIBOLREC) AND
                   (NRLANBOLREC  = @V_CNTBOL_NRLANBOLREC)) A

            /* - O BOLETO POSSUI CONTAS ASSOCIADAS DE DUPLICATAS DIFERENTES ---- */
            IF @V_NRBOLETO > 1 BEGIN
               SET @P_IDRESULT = 'D';
            END;

            FETCH NEXT FROM C_CNTBOL INTO @V_CNTBOL_CDFILIBOLREC, @V_CNTBOL_NRLANBOLREC;
         END;
         CLOSE C_CNTBOL;
         DEALLOCATE C_CNTBOL;
   END
   ELSE BEGIN
      SET @P_IDRESULT = 'E';
   END;

   IF @P_NRLANBOLREC = '' BEGIN
      SET @P_IDRESULT = 'F';
   END;

   /* - VERIFICA SE O BOLETO J FOI BAIXADO ---------------------------------- */
   SELECT
      @V_NRBOLBAIXADO = COUNT(*)
   FROM
      CONTARECEBER CR,
      BOLETRECEBER BO
   WHERE
      (CDFILIALDUP    = @P_CDFILIAL)     AND
      (NRLANCTODUP    = @P_NRLANCTODUP)  AND
      (BO.CDFILIAL    = CR.CDFILIBOLREC) AND
      (BO.NRLANBOLREC = CR.NRLANBOLREC)  AND
      (BO.NRBAIXAREC IS NOT NULL);

   IF @V_NRBOLBAIXADO > 0 BEGIN
      SET @P_IDRESULT = 'I';
   END;

   /* - VERIFICA SE O BOLETO DE DUPLICATA FOI PARCELAD0 ----------------------------------*/
   SELECT @V_NRPARCELA = COUNT(DISTINCT CDFILIBOLREC+NRLANBOLREC)
     FROM CONTARECEBER
    WHERE CDFILIALDUP = @P_CDFILIAL
      AND NRLANCTODUP = @P_NRLANCTODUP;

   IF @V_NRPARCELA > 1 BEGIN
      SET @P_IDRESULT = 'H';
   END;

   /* - VERIFICA SE A CONTA FOI PRORROGADA ----------------------------------
   SELECT
      COUNT(*)
   INTO
      V_NRCNTPROR
   FROM
      CONTARECEBER
   WHERE
      (CDFILIALDUP  = P_CDFILIAL)    AND
      (NRLANCTODUP  = P_NRLANCTODUP) AND
      (DTORIGVENREC <> DTATUAVENREC)  AND
      (NRLANBOLREC IS NOT NULL);

   IF V_NRCNTPROR > 0 THEN
      P_IDRESULT := 'L';
   END IF;
   */
   -- VERIFICA SE A DUPLICATA ESTA LIGADA A UM CNABR
   SELECT
      @V_NRCNTPROR = COUNT(*)
   FROM
      CONTARECEBER CR,
      BOLETRECEBER BO
   WHERE
      (CDFILIALDUP    = @P_CDFILIAL    ) AND
      (NRLANCTODUP    = @P_NRLANCTODUP ) AND
      (BO.CDFILIAL    = CR.CDFILIBOLREC) AND
      (BO.NRLANBOLREC = CR.NRLANBOLREC ) AND
      (IDSITUCNABR <> '00')              AND 
      (IDSITUCNABR IS NOT NULL);
      
   IF @V_NRCNTPROR > 0 BEGIN
      SET @P_IDRESULT = 'M';
   END;
   
   IF @P_IDRESULT = 'N' BEGIN
      SELECT
      	@V_CDFILIBOLREC = MAX(CDFILIBOLREC),
      	@V_NRLANBOLREC = MAX(NRLANBOLREC)
      FROM
         CONTARECEBER
      WHERE
	      (CDFILIALDUP = @P_CDFILIAL) AND
   	   (NRLANCTODUP = @P_NRLANCTODUP);

      /* -- APAGA A CHAVE DA DUPLICATA ------------------------------ */
      UPDATE CONTARECEBER
      SET
         CDFILIALDUP = NULL,
         NRLANCTODUP = NULL
      WHERE
         (CDFILIALDUP = @P_CDFILIAL) AND
         (NRLANCTODUP = @P_NRLANCTODUP);

      SET @V_NRPRXLANBOL = @P_NRLANBOLREC;
      SET @V_CHAVE_NOTA = '';
      DECLARE C_CONTREC CURSOR FOR
         SELECT CDFILIAL,
                NRLANCTONF,
                NRSEQVENREC,
                NRPARCELAREC,
                CDTPCTRECEB
         FROM
            CONTARECEBER
         WHERE
            (CDFILIBOLREC = @V_CDFILIBOLREC) AND
            (NRLANBOLREC  = @V_NRLANBOLREC)
         ORDER BY CDFILIAL, NRLANCTONF;

      OPEN C_CONTREC;

      FETCH NEXT FROM C_CONTREC INTO @V_CNTREC_CDFILIAL, @V_CNTREC_NRLANCTONF,
                                    @V_CNTREC_NRSEQVENREC, @V_CNTREC_NRPARCELAREC,
                                    @V_CNTREC_CDTPCTRECEB;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         IF (@V_CHAVE_NOTA <> (@V_CNTREC_CDFILIAL + @V_CNTREC_NRLANCTONF)) BEGIN
            /*VERIFICA A QUANTIDADE DE CONTAS QUE IRO SER ATUALIZADAS */
            SELECT @V_COUNT = COUNT(*)
              FROM CONTARECEBER
             WHERE CDFILIAL = @V_CNTREC_CDFILIAL
               AND NRLANCTONF = @V_CNTREC_NRLANCTONF
               AND CDFILIBOLREC = @V_CDFILIBOLREC
               AND NRLANBOLREC = @V_NRLANBOLREC;
            /* -- INCLUI O NOVO BOLETO ---------------------------------------------*/
            EXEC GERA_BOLETOS @V_CNTREC_CDFILIAL,
                              @V_CNTREC_NRLANCTONF,
                              @V_CDFILIBOLREC,
                              @V_NRPRXLANBOL,
                              @V_CNTREC_CDTPCTRECEB,
                              'S',
                              @V_CDFILIBOLREC,
                              @V_NRLANBOLREC;

            SET @V_NRPRXLANBOL = RIGHT(REPLICATE('0',10)+CONVERT(VARCHAR,CONVERT(INTEGER,@V_NRPRXLANBOL) + @V_COUNT),10);
            SET @V_CHAVE_NOTA = @V_CNTREC_CDFILIAL + @V_CNTREC_NRLANCTONF;
         END;
         FETCH NEXT FROM C_CONTREC INTO @V_CNTREC_CDFILIAL, @V_CNTREC_NRLANCTONF,
                                        @V_CNTREC_NRSEQVENREC, @V_CNTREC_NRPARCELAREC,
                                        @V_CNTREC_CDTPCTRECEB;
      END;
      CLOSE C_CONTREC;
      DEALLOCATE C_CONTREC;

      /* - APAGA O BOLETO, SEUS AJUSTE E O FLUXO DE CAIXA ---------------------- */
      SELECT @V_CTAJBOL = COUNT(*)
      FROM AJBOLREC
      WHERE
         (CDFILIAL    = @V_CDFILIBOLREC) AND
         (NRLANBOLREC = @V_NRLANBOLREC);

      IF @V_CTAJBOL > 0 BEGIN
         DECLARE C_AJBOL CURSOR FOR
            SELECT
               MR.CDCLASSFINA,  MR.CDEMPRESA,    MR.CDFILIAL,    MR.DTMOVFLUXO,
               MR.IDMOVFLUXO,   MR.CDFILIBOLREC, MR.NRLANBOLREC, MR.CDAJUCTREC,
               MR.VRFXAJBOLREC, TA.IDAJUCTREC
            FROM
               TIPOAJRECEBER TA, MOVFXAJBOLR MR
            WHERE
               (MR.CDFILIBOLREC = @V_CDFILIBOLREC) AND
               (MR.NRLANBOLREC  = @V_NRLANBOLREC)  AND
               (TA.CDAJUCTREC   = MR.CDAJUCTREC)

         OPEN C_AJBOL;

         FETCH NEXT FROM C_AJBOL INTO @V_AJBOL_CDCLASSFINA,  @V_AJBOL_CDEMPRESA,
                                      @V_AJBOL_CDFILIAL,     @V_AJBOL_DTMOVFLUXO,
                                      @V_AJBOL_IDMOVFLUXO,   @V_AJBOL_CDFILIBOLREC,
                                      @V_AJBOL_NRLANBOLREC,  @V_AJBOL_CDAJUCTREC,
                                      @V_AJBOL_VRFXAJBOLREC, @V_AJBOL_IDAJUCTREC;

         WHILE (@@FETCH_STATUS = 0) BEGIN

            IF @V_AJBOL_IDAJUCTREC = 'A' BEGIN

               SET @V_AJBOL_VRFXAJBOLREC = @V_AJBOL_VRFXAJBOLREC * -1;
               EXEC ATUALIZA_FLUXO_DE_CAIXA @V_AJBOL_CDEMPRESA,
                                            @V_AJBOL_CDFILIAL,
                                            @V_AJBOL_DTMOVFLUXO,
                                            @V_AJBOL_IDMOVFLUXO,
                                            @V_AJBOL_CDCLASSFINA,
                                            @V_AJBOL_VRFXAJBOLREC,
                                            0;
            END
            ELSE BEGIN
               EXEC ATUALIZA_FLUXO_DE_CAIXA @V_AJBOL_CDEMPRESA,
                                            @V_AJBOL_CDFILIAL,
                                            @V_AJBOL_DTMOVFLUXO,
                                            @V_AJBOL_IDMOVFLUXO,
                                            @V_AJBOL_CDCLASSFINA,
                                            @V_AJBOL_VRFXAJBOLREC,
                                            0;
            END;

            FETCH NEXT FROM C_AJBOL INTO @V_AJBOL_CDCLASSFINA,  @V_AJBOL_CDEMPRESA,
                                         @V_AJBOL_CDFILIAL,     @V_AJBOL_DTMOVFLUXO,
                                         @V_AJBOL_IDMOVFLUXO,   @V_AJBOL_CDFILIBOLREC,
                                         @V_AJBOL_NRLANBOLREC,  @V_AJBOL_CDAJUCTREC,
                                         @V_AJBOL_VRFXAJBOLREC, @V_AJBOL_IDAJUCTREC;

         END;
         CLOSE C_AJBOL;
         DEALLOCATE C_AJBOL;

         DELETE FROM MOVFXAJBOLR
         WHERE
            (CDFILIBOLREC = @V_CDFILIBOLREC) AND
            (NRLANBOLREC  = @V_NRLANBOLREC);

         DELETE FROM AJBOLREC
         WHERE
            (CDFILIAL    = @V_CDFILIBOLREC) AND
            (NRLANBOLREC = @V_NRLANBOLREC);
      END;

   	DELETE FROM BOLETRECEBER
      WHERE
         (CDFILIAL    = @V_CDFILIBOLREC) AND
         (NRLANBOLREC = @V_NRLANBOLREC);

      /* -- INCLUI UM BOLETO PARA CADA CONTA -------------------------
      V_NRPRXLANBOL := P_NRLANBOLREC;
      FOR C_CONTA IN
         (SELECT
             CDFILIAL,
             NRLANCTONF,
             NRSEQVENREC,
             NRPARCELAREC,
             DTORIGVENREC,
             DTATUAVENREC,
        	    CDFILIBOLREC,
        	    NRLANBOLREC,
             CDEMPRESA,
             CDFIMOVFLREC,
             DTMOVFLUXO,
             IDMOVFLUXO,
             CDCLASSFINA,
             VRORIGREC
          FROM
             CONTARECEBER
          WHERE
             (CDFILIALDUP = P_CDFILIAL) AND
             (NRLANCTODUP = P_NRLANCTODUP)
         ) LOOP

         IF C_CONTA.DTORIGVENREC <> C_CONTA.DTATUAVENREC THEN
            - ATUALIZA O FLUXO DE CAIXA --------------------------
            ATUALIZA_FLUXO_DE_CAIXA(C_CONTA.CDEMPRESA,
                                    C_CONTA.CDFIMOVFLREC,
                                    C_CONTA.DTMOVFLUXO,
                                    C_CONTA.IDMOVFLUXO,
                                    C_CONTA.CDCLASSFINA,
                                    C_CONTA.VRORIGREC * -1,
                                    0);

            ATUALIZA_FLUXO_DE_CAIXA(C_CONTA.CDEMPRESA,
                                    C_CONTA.CDFIMOVFLREC,
                                    C_CONTA.DTORIGVENREC,
                                    C_CONTA.IDMOVFLUXO,
                                    C_CONTA.CDCLASSFINA,
                                    C_CONTA.VRORIGREC,
                                    0);

            UPDATE CONTARECEBER
            SET
               DTATUAVENREC = C_CONTA.DTORIGVENREC,
               CDMOTIPROR   = NULL,
               DTMOVFLUXO   = C_CONTA.DTORIGVENREC
            WHERE
               (CDFILIAL     = C_CONTA.CDFILIAL)     AND
               (NRLANCTONF   = C_CONTA.NRLANCTONF)   AND
               (NRSEQVENREC  = C_CONTA.NRSEQVENREC)  AND
               (NRPARCELAREC = C_CONTA.NRPARCELAREC);

             -- ATUALIZA O FLUXO DE CAIXA DOS AJUSTES DA CONTA -------------
            SELECT
               COUNT(*)
            INTO
               V_NRREGFOR
            FROM
               AJCTRECEBER
            WHERE
               (CDFILIAL     = C_CONTA.CDFILIAL)    AND
               (NRLANCTONF   = C_CONTA.NRLANCTONF)  AND
               (NRSEQVENREC  = C_CONTA.NRSEQVENREC) AND
               (NRPARCELAREC = C_CONTA.NRPARCELAREC);

            IF V_NRREGFOR > 0 THEN
             	FOR C_AJUSTE IN
                  (SELECT
                      CDFILIAL,
                      NRLANCTONF,
                      NRSEQVENREC,
                      NRPARCELAREC,
                      DTAJUSTEREC,
                      CDAJUCTREC,
                      CDCLASSFINA,
                      CDEMMFAJCNTR,
                      CDFIMFAJCNTR,
                      DTMOVFLUXO,
                      IDMOVFLUXO,
                      VRAJUSTEREC
                   FROM
                      AJCTRECEBER
                   WHERE
                      (CDFILIAL     = C_CONTA.CDFILIAL)     AND
                      (NRLANCTONF   = C_CONTA.NRLANCTONF)   AND
                      (NRSEQVENREC  = C_CONTA.NRSEQVENREC)  AND
                      (NRPARCELAREC = C_CONTA.NRPARCELAREC)
                  ) LOOP

                  ATUALIZA_FLUXO_DE_CAIXA(C_AJUSTE.CDEMMFAJCNTR,
                                          C_AJUSTE.CDFIMFAJCNTR,
                                          C_AJUSTE.DTMOVFLUXO,
                                          C_AJUSTE.IDMOVFLUXO,
                                          C_AJUSTE.CDCLASSFINA,
                                          C_AJUSTE.VRAJUSTEREC * -1,
                                          0);

                  ATUALIZA_FLUXO_DE_CAIXA(C_AJUSTE.CDEMMFAJCNTR,
                                          C_AJUSTE.CDFIMFAJCNTR,
                                          C_CONTA.DTORIGVENREC,
                                          C_AJUSTE.IDMOVFLUXO,
                                          C_AJUSTE.CDCLASSFINA,
                                          C_AJUSTE.VRAJUSTEREC,
                                          0);

                  UPDATE AJCTRECEBER
                  SET DTMOVFLUXO = C_CONTA.DTORIGVENREC
                  WHERE
                     (CDFILIAL     = C_AJUSTE.CDFILIAL)     AND
                     (NRLANCTONF   = C_AJUSTE.NRLANCTONF)   AND
                     (NRSEQVENREC  = C_AJUSTE.NRSEQVENREC)  AND
                     (NRPARCELAREC = C_AJUSTE.NRPARCELAREC) AND
                     (DTAJUSTEREC  = C_AJUSTE.DTAJUSTEREC)  AND
                     (CDAJUCTREC   = C_AJUSTE.CDAJUCTREC)   AND
                     (CDCLASSFINA  = C_AJUSTE.CDCLASSFINA);
               END LOOP;
            END IF;
         END IF;


         V_PEMULTA := 0;
         V_PEMORA  := 0;

         SELECT
            MAX(CL.CDCLIENTE),
            MAX(CL.VRPEMULBCLI),
            MAX(CL.VRPEMORBCLI)
         INTO
            V_CDCLIENTE,
            V_PEMULTA,
            V_PEMORA
         FROM
            CONTARECEBER CR,
            NOTAFISCAL   NF,
            CLIENTE      CL
         WHERE
            (CR.CDFILIALDUP = P_CDFILIAL)    AND
            (CR.NRLANCTODUP = P_NRLANCTODUP) AND
            (NF.CDFILIAL    = CR.CDFILIAL)   AND
            (NF.NRLANCTONF  = CR.NRLANCTONF) AND
            (CL.CDCLIENTE   = NF.CDCLIENTE);

         IF (V_PEMULTA IS NULL) OR
            (V_PEMORA  IS NULL) THEN
            SELECT
               MAX(VRPEMULEMPR),
               MAX(VRPEMOREMPR)
            INTO
               V_PEMULTA,
               V_PEMORA
            FROM
               EMPRESA
            WHERE
               (CDEMPRESA = C_CONTA.CDEMPRESA);
         END IF;

         INSERT INTO BOLETRECEBER(
            CDFILIAL,
            NRLANBOLREC,
            CDCLIENTE,
            CDEMPRESA,
            VRBOLREC,
            VRPEMULBREC,
            VRPEMORBREC,
            VRFINALBREC,
            DTVENBOLREC,
            CDNOSNUMREC)
         VALUES(
            P_CDFILIAL,
            V_NRPRXLANBOL,
            V_CDCLIENTE,
            C_CONTA.CDEMPRESA,
            C_CONTA.VRORIGREC,
            V_PEMULTA,
            V_PEMORA,
            C_CONTA.VRORIGREC,
            C_CONTA.DTORIGVENREC,
            P_CDFILIAL||V_NRPRXLANBOL);

          -- GRAVA A CHAVE DO NOVO BOLETO NAS CONTAS DA DUPLICATA -------------
         UPDATE CONTARECEBER
         SET
            CDFILIBOLREC = P_CDFILIAL,
            NRLANBOLREC  = V_NRPRXLANBOL
         WHERE
            (CDFILIAL     = C_CONTA.CDFILIAL)     AND
            (NRLANCTONF   = C_CONTA.NRLANCTONF)   AND
            (NRSEQVENREC  = C_CONTA.NRSEQVENREC)  AND
            (NRPARCELAREC = C_CONTA.NRPARCELAREC);

         V_NRPRXLANBOL := TO_CHAR(TO_NUMBER(V_NRPRXLANBOL) + 1);
         V_NRPRXLANBOL := LPAD(V_NRPRXLANBOL, 10, '0');
      END LOOP;
 */
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'EXCLUSAO_DE_DUPLICATA','5.01.003';
GO
